#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 criterion-measurement
version:              0.1.2.0
visibility:           public
id:                   criterion-measurement-0.1.2.0-1MgKbyb1P6GRL6iYLoNZN
key:                  criterion-measurement-0.1.2.0-1MgKbyb1P6GRL6iYLoNZN
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  bc458055da8f16692669c6d7da000352
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:
    /usr/lib/ghc-8.10.5/site-local/criterion-measurement-0.1.2.0

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/criterion-measurement-0.1.2.0

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/criterion-measurement-0.1.2.0

hs-libraries:         HScriterion-measurement-0.1.2.0-1MgKbyb1P6GRL6iYLoNZN
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ base-4.14.2.0
    base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK binary-0.8.8.0
    containers-0.6.4.1 deepseq-1.4.4.0
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

